#!/usr/bin/env python
import plistlib
from shutil import copy
import subprocess
import os
from tempfile import gettempdir
import sys
import atexit

BOOKMARKS_PLIST = '~/Library/Safari/Bookmarks.plist'
bookmarksFile = os.path.expanduser(BOOKMARKS_PLIST)

# Make a copy of the bookmarks and convert it from a binary plist to text
tempDirectory = gettempdir()
copy(bookmarksFile, tempDirectory)
bookmarksFileCopy = os.path.join(tempDirectory, os.path.basename(bookmarksFile))


def removeTempFile():
    os.remove(bookmarksFileCopy)


atexit.register(removeTempFile)  # Delete the temp file when the script finishes

converted = subprocess.call(['plutil', '-convert', 'xml1', bookmarksFileCopy])

if converted != 0:
    print "Couldn't convert bookmarks plist from xml format"
    sys.exit(converted)

plist = plistlib.readPlist(bookmarksFileCopy)
# There should only be one Reading List item, so take the first one
readingList = [item for item in plist['Children'] if 'Title' in item and item['Title'] == 'com.apple.ReadingList'][0]

if 'Children' in readingList:
    n = 0
    file = open("readinglistdb.txt", "w")
    for item in readingList['Children']:
        try:
            thisrecord = ""

            title_nsync = item.get("ReadingListNonSync").get("Title")
            title_rl = item.get("ReadingList").get("Title")
            title_uri = item.get("URIDictionary").get("title")
            lastdate_nsync = item.get("ReadingListNonSync").get("DateLastFetched")
            lastdate_rl = item.get("ReadingList").get("DateLastFetched")
            uuid = item['WebBookmarkUUID']
            url = item['URLString']
            # print item.get("ReadingListNonSync").get("DateLastFetched")
            if uuid is None:
                uuid = ""
            # if lastdate is None:
            #    slastdate = ""

            if title_nsync is None:
                if title_rl is None:
                    if title_uri is None:
                        title = ""
                    else:
                        title = title_uri
                else:
                    title = title_rl
            else:
                title = title_nsync

            title = title.replace("\n", " - ")
            # assert isinstance(url, object)

            if lastdate_nsync is None:
                if lastdate_rl is None:
                    slastdate = ""
                else:
                    slastdate = lastdate_rl.strftime('%d.%m.%Y %H:%M:%S')
            else:
                slastdate = lastdate_nsync.strftime('%d.%m.%Y %H:%M:%S')

            if url is None:
                url = ""

            # slastdate = lastdate.strftime('%d.%m.%Y')
            n += 1

            thisrecord = str(n) + ";; " + title + ";; " + slastdate + ";; " + url + ";; " + uuid
            print thisrecord
            file.writelines(thisrecord + '\n')


        except BaseException, e:
            # logger.error('Failed to upload to ftp: '+ str(e))
            print "ERROR: " + str(e)

    file.close()